@@ -51,7 +51,7 @@ exports.db = function (req, res) {
 }
 
 exports.jdbc = function (req, res) {
-    req.jdbc.query("mssql", "SELECT *  FROM  contract_type", [], function (err, data) {
+    req.jdbc.query("mysql", "SELECT *  FROM  contract_type", [], function (err, data) {
         res.send(data);
 
         
