@@ -36,8 +36,8 @@ var config = {
         name: "mysql",
         driver: "com.mysql.jdbc.Driver",
         url: "jdbc:mysql://db.codeunbug.com:3306/rmut_expert_db",
-        user: "xx",
-        password: "xx"
+        user: "root",
+        password: "ChangDao@2013"
         
       },
       {
