@@ -29,14 +29,19 @@ module.exports = function (session) {
     this.db = options.db || 'oauth';
     this.table = options.table || 'session';
     this.debug = options.debug || false;
+    var seft=this;
 
-    r.db(this.db).tableList().contains(this.table).run().then(function (d) {
-      if (d == false) {
-        r.db(this.db).tableCreate(this.table).run().then(function (d) { });
-      }
+    
+    r.db(seft.db).tableList().contains(seft.table).run().then(function (d) {
+       //  console.log("xxxxxxxxxxxxxxxxxxx");
+         console.log(d);
+        if (d == false) {
+            r.db(seft.db).tableCreate(seft.table).run().then(function (d) { });
+        }else{
+
+        }
     });
 
-
     setInterval(function () {
       try {
         r.db(this.db).table(this.table).filter(r.row('expires').lt(r.now().toEpochTime().mul(1000))).delete().run(function (err, user) {
